import 'dart:convert'; // Para convertir datos a JSON
import 'package:flutter/foundation.dart';
import 'package:http/http.dart' as http;
import 'package:primer_practica/environments/urls.dart' as api;
import 'package:primer_practica/src/models/categoryModel.dart';

class CategoryService {
  static const String apiBaseUrl = 'categoria';

  // Método para obtener las categorías
  Future<Map<String, dynamic>> getCategories({int offset = 0, int max = 100}) async {
    final String url = '${api.apiApp}/$apiBaseUrl?offset=$offset&max=$max';

    if (kDebugMode) {
      print('Url -> $url');
    }

    try {
      final response = await http.get(Uri.parse(url));
      return {
        'statusCode': response.statusCode,
        'body': response.body,
      };
    } catch (e) {
      return {
        'statusCode': 501,
        'body': '$e',
      };
    }
  }

  // Método para enviar una nueva categoría al servidor
  Future<Map<String, dynamic>> postCategory(CategoryModel category) async {
    final String url = '${api.apiApp}/$apiBaseUrl';

    //conversión del objeto a Json
    final categoryJson = category.toJson();

    // Imprime la URL y el cuerpo de la solicitud
    if (kDebugMode) {
      print('Url -> $url');
      print('Body -> $categoryJson');
    }

    try {
      // Realiza la solicitud POST al servidor
      final response = await http.post(
        Uri.parse(url), // Convierte la URL a un objeto Uri
        headers: {'Content-Type': 'application/json'}, // Establece el tipo de contenido como JSON
        body: json.encode(categoryJson),
      );

      return {
        'statusCode': response.statusCode,
        'body': response.body,
      };
    } catch (e) {

      return {
        'statusCode': 501,
        'body': '$e',
      };
    }
  }

}
