import 'package:flutter/material.dart';
import 'package:primer_practica/src/controllers/categoty_controller.dart';
import 'package:primer_practica/src/pages/articles_page.dart';
import 'package:primer_practica/src/shared_widgets/widget_mensajes.dart' as msg_shared;
import 'package:primer_practica/src/models/categoryModel.dart';

class ListaCategorias extends StatelessWidget {
  final CategoryController categoryCtrl = CategoryController(); // Crea una instancia del controlador de categorías

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: Padding(
        padding: const EdgeInsets.all(16.0),
        child: FutureBuilder(
          future: categoryCtrl.getCategories(), // Llama al método getCategories del controlador
          builder: (context, AsyncSnapshot<Map<String, dynamic>> snapshot) {
            if (snapshot.hasData) {
              if (snapshot.data!['ok']) {
                if (snapshot.data!['data'].length > 0) {
                  return ListView.builder(
                    itemBuilder: (BuildContext context, int index) {
                      CategoryModel category = snapshot.data!['data'][index];
                      return Card(
                        child: ListTile(
                          title: Text(category.name?? 'No Name'), // Muestra el nombre de la categoría
                          leading: const Icon(Icons.touch_app),
                          onTap: () {
                            Navigator.push(
                              context,
                              MaterialPageRoute(
                                builder: (context) => ArticlePage(categoryId: category.id),
                              ),
                            );
                            // Navegar al listado de servicios
                          },
                        ),
                      );
                    },
                    itemCount: snapshot.data!['data'].length,
                  );
                } else {
                  return msg_shared.alertWait("No se encontraron categorías");
                }
              } else {
                return msg_shared.alertDanger("Error: ${snapshot.data!['message']}");
              }
            } else if (snapshot.hasError) {
              return msg_shared.alertDanger("Error: ${snapshot.error.toString()}");
            } else {
              return const Center(
                child: CircularProgressIndicator(), // Muestra un indicador de progreso mientras se cargan los datos
              );
            }
          },
        ),
      ),
    );
  }
}
