import 'package:flutter/material.dart';
import 'package:primer_practica/src/controllers/categoty_controller.dart';
import 'package:primer_practica/src/models/categoryModel.dart';
import 'package:primer_practica/src/config/routes.dart';

class FormularioCategoria extends StatefulWidget {
  const FormularioCategoria({super.key});

  @override
  _FormularioCategoriaState createState() => _FormularioCategoriaState();
}

class _FormularioCategoriaState extends State<FormularioCategoria> {
  final _nombreController = TextEditingController();
  final _claveController = TextEditingController();
  final CategoryController _categoryController = CategoryController(); // Instancia del controlador

  @override
  void dispose() {
    _nombreController.dispose();
    _claveController.dispose();
    super.dispose();
  }

  Future<void> _guardarCategoria() async {
    final nombre = _nombreController.text; // Obtiene el valor de nombre y clave
    final clave = _claveController.text;

    if (nombre.isEmpty || clave.isEmpty) {
      ScaffoldMessenger.of(context).showSnackBar(
        const SnackBar(content: Text('Por favor, complete todos los campos')),
      );
      return;
    }

    final fechaCreado = DateTime.now().millisecondsSinceEpoch;

    final categoria = CategoryModel(
      id: 0,
      key: clave,
      name: nombre,
      createdDate: fechaCreado,
    );

    final result = await _categoryController.addCategory(categoria); // Llama al método para agregar categoría

    if (result['ok']) {
      ScaffoldMessenger.of(context).showSnackBar(
        SnackBar(content: Text(result['message'])), // Muestra mensaje de éxito
      );

      Navigator.pop(context);
      Navigator.pushNamed(context, 'home');
    } else {
      ScaffoldMessenger.of(context).showSnackBar(
        SnackBar(content: Text(result['message'])),
      );
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('Agregar Categoría'),
      ),
      body: Padding(
        padding: const EdgeInsets.all(16.0), // Ajuste del padding para un diseño más estético
        child: Column(
          children: <Widget>[
            TextField(
              controller: _claveController,
              decoration: const InputDecoration(labelText: 'Clave'),
              keyboardType: TextInputType.text,
            ),
            const SizedBox(height: 16), // Ajuste del espacio entre campos
            TextField(
              controller: _nombreController,
              decoration: const InputDecoration(labelText: 'Nombre'),
              keyboardType: TextInputType.text,
            ),
            const SizedBox(height: 24), // Ajuste del espacio entre campos y botón
            ElevatedButton(
              onPressed: _guardarCategoria,
              child: const Text('GUARDAR'),
            ),
          ],
        ),
      ),
    );
  }
}
